<?php
/*
Plugin Name: Laskuhari for WooCommerce
Plugin URI: https://www.laskuhari.fi/woocommerce-laskutus
Description: Lisää automaattilaskutuksen maksutavaksi WooCommerce-verkkokauppaan sekä mahdollistaa tilausten manuaalisen laskuttamisen
Version: 0.9.15
Author: Datahari Solutions
Author URI: https://www.datahari.fi
License: GPLv2
*/

/*
Based on WooCommerce Custom Payment Gateways
Author: Mehdi Akram
Author URI: http://shamokaldarpon.com/
*/

//Additional links on the plugin page
add_filter( 'plugin_row_meta', 'LHPG_register_plugin_links', 10, 2 );
function LHPG_register_plugin_links($links, $file) {
    $base = plugin_basename(__FILE__);
    if ($file == $base) {
        $links[] = '<a href="https://oma.laskuhari.fi/" target="_blank">' . __( 'Kirjaudu Laskuhariin', 'rsb' ) . '</a>';
    }
    return $links;
}


/* WooCommerce fallback notice. */
function woocommerce_laskuhari_fallback_notice() {
    echo '<div class="error"><p>' . sprintf( __( 'WooCommerce Laskuhari Payment Gateway depends on the last version of %s to work!', 'LHPG' ), '<a href="http://wordpress.org/extend/plugins/woocommerce/">WooCommerce</a>' ) . '</p></div>';
}

/* Load functions. */
function laskuhari_payment_gateway_load() {
    if ( ! class_exists( 'WC_Payment_Gateway' ) ) {
        add_action( 'admin_notices', 'woocommerce_laskuhari_fallback_notice' );
        return;
    }
   
    function laskuhari_add_gateway( $methods ) {
        $methods[] = 'WC_Gateway_Laskuhari';
        return $methods;
    }
    add_filter( 'woocommerce_payment_gateways', 'laskuhari_add_gateway' );
    
    
    // Include the WooCommerce Custom Payment Gateways classes.
    require_once plugin_dir_path( __FILE__ ) . 'class-wc-gateway-laskuhari.php';

    $laskuhari = new WC_Gateway_Laskuhari(true);
    if($laskuhari->get_option('enabled') == 'yes') {
        add_action( 'admin_print_scripts', 'laskuhari_add_scripts' );
        add_action( 'admin_print_styles', 'laskuhari_add_styles' );
        //add_filter( 'post_row_actions', 'laskuhari_laskuta', 10, 2 );
        add_action( 'woocommerce_admin_order_actions_end', 'laskuhari_laskuta' );
        laskuhari_actions();
    }

    /**
    * Add Settings link to the plugin entry in the plugins menu for WC below 2.1
    **/
    if ( version_compare( WOOCOMMERCE_VERSION, "2.1" ) <= 0 ) {

        add_filter('plugin_action_links', 'laskuhari_plugin_action_links', 10, 2);

        function laskuhari_plugin_action_links($links, $file) {
            static $this_plugin;

            if (!$this_plugin) {
                $this_plugin = plugin_basename(__FILE__);
            }

            if ($file == $this_plugin) {
                $settings_link = '<a href="' . get_bloginfo('wpurl') . '/wp-admin/admin.php?page=wc-settings&tab=checkout&section=laskuhari">Asetukset</a>';
                array_unshift($links, $settings_link);
            }
            return $links;
        }
    }
    /**
    * Add Settings link to the plugin entry in the plugins menu for WC 2.1 and above
    **/
    else{
        add_filter('plugin_action_links', 'laskuhari_plugin_action_links', 10, 2);

        function laskuhari_plugin_action_links($links, $file) {
            static $this_plugin;

            if (!$this_plugin) {
                $this_plugin = plugin_basename(__FILE__);
            }

            if ($file == $this_plugin) {
                $settings_link = '<a href="' . get_bloginfo('wpurl') . '/wp-admin/admin.php?page=wc-settings&tab=checkout&section=laskuhari">Asetukset</a>';
                array_unshift($links, $settings_link);
            }
            return $links;
        }
    }
}

add_action( 'plugins_loaded', 'laskuhari_payment_gateway_load', 0 );

function laskuhari_actions() {
    if($_GET['action'] == "laskuhari-batch-send") {
        $order_ids = array();
        $notices   = array();
        $successes = array();

        foreach( $_GET['post'] as $order_id ) {
            $lh = laskuhari_process_action($order_id, true);
            $order      = $lh['order'];
            $notice     = $lh['notice'];
            $success    = $lh['success'];

            $order_ids[] = $order->id;
            $notices[]   = urlencode($notice);
            $successes[] = urlencode($success);
        }

        $back = remove_query_arg(array('_wpnonce', 'order_id', 'laskuhari', 'post', 'action'));
        $back = add_query_arg(array('laskuhari_lahetetty' => $order_ids, 'laskuhari_notice' => $notices, 'laskuhari_success' => $successes), $back);
        wp_redirect($back);
        exit;
    }
    if($_GET['laskuhari'] == "send") {
        $lh         = laskuhari_process_action($_GET['order_id'] ? $_GET['order_id'] : $_GET['post'], true);
        $order      = $lh['order'];
        $notice     = $lh['notice'];
        $success    = $lh['success'];

        $back = remove_query_arg(array('_wpnonce', 'order_id', 'laskuhari'));
        $back = add_query_arg(array('laskuhari_lahetetty' => $order->id, 'laskuhari_notice' => urlencode($notice), 'laskuhari_success' => urlencode($success)), $back);
        wp_redirect($back);
        exit;
    }
    if($_GET['laskuhari_download'] > 0) {
        laskuhari_download($_GET['laskuhari_download'], $_GET['order_id']);
    }
}

if($_GET['laskuhari_lahetetty']) {
    add_action( 'admin_notices', 'laskuhari_lahetetty' );
}

function laskuhari_lahetetty() {
    $notices = is_array($_GET['laskuhari_notice']) ? $_GET['laskuhari_notice'] : array($_GET['laskuhari_notice']);
    $successes = is_array($_GET['laskuhari_success']) ? $_GET['laskuhari_success'] : array($_GET['laskuhari_success']);
    $order_ids = is_array($_GET['laskuhari_lahetetty']) ? $_GET['laskuhari_lahetetty'] : array($_GET['laskuhari_lahetetty']);
    foreach( $notices as $key => $notice ) {
        if($notice != "") {
            echo '<div class="notice notice-error is-dismissible"><p>'.htmlspecialchars($_GET['laskuhari_notice']).'</p></div>';
        } else {
            $success = $successes[$key] ? $successes[$key] : 'Tilaus #'.$order_ids[$key].' laskutettu.';
            echo '<div class="notice notice-success is-dismissible"><p>'.htmlspecialchars($success).'</p></div>'; 
        }
    }
}
function laskuhari_add_styles() {
    wp_enqueue_style(
        'laskuhari-css',
        plugins_url('css/staili.css' , __FILE__),
        array()
    );
}
function laskuhari_add_scripts() {
    wp_enqueue_script(
        'laskuhari-js',
        plugins_url('js/js.js' , __FILE__),
        array('jquery')
    );
}

    
function laskuhari_laskuta($order){    
    
    if ($order->post->post_type=='shop_order') {
        
        $url = admin_url( 'edit.php?post_type=shop_order&order_id=' . $order->id );

        $sent = get_post_meta($order->id, '_laskuhari_sent', true);
        $invoice_number = get_post_meta($order->id, '_laskuhari_invoice_number', true);
        if($sent == "yes") {
            $uud = " uudelleen?";
            if(!$invoice_number) {
                $uud .= " Lasku luodaan uutena laskuna.";
            }
            $uud2 = " uudelleen";
            $img = "_sent";
        } else {
            $uud = "?";
            $uud2 = "";
            $img = "";
        }
        
        $send_create_invoice_link = wp_nonce_url( add_query_arg( array( 'laskuhari' => 'send', 'laskuhari_invoice_number' => $invoice_number ), $url ), 'edit_order_nonce' );
        $download_invoice_link = wp_nonce_url( add_query_arg( array( 'laskuhari_download' => $invoice_number ), $url ), 'edit_order_nonce' );
        
        // show buttons only on processing and completed orders
        if ( $order->status != 'processing' && $order->status != 'completed' ) {
            return;
        }
        ?>
        <a onclick="if(!confirm('Haluatko varmasti lähettää laskun tilauksesta<?php echo $uud; ?>')) {return false;} else {laskuhari_loading();}" href="<?php echo $send_create_invoice_link; ?>" class="button tips laskuhari-invoice" alt="Lähetä lasku asiakkaalle<?php echo $uud2; ?>" data-tip="Lähetä lasku asiakkaalle<?php echo $uud2; ?>">
            <img src="<?php echo plugins_url( 'images/invoice'.$img.'.png' , __FILE__ ); ?>" alt="Lähetä lasku asiakkaalle<?php echo $uud2; ?>" width="32">
        </a>
        <?php
        if($invoice_number > 0) {
            ?>
            <a href="<?php echo $download_invoice_link; ?>" target="_blank" class="button tips laskuhari-invoice" alt="Lataa laskun PDF-tiedosto" data-tip="Lataa laskun PDF-tiedosto">
                <img src="<?php echo plugins_url( 'images/invoice_download.png' , __FILE__ ); ?>" alt="Lataa laskun PDF-tiedosto" width="32">
            </a>
            <?php
        }


    }
            
}

function laskuhari_download($invoice_number, $order_id) {
    // laskunlähetyksen asetukset
    $info = new WC_Gateway_Laskuhari(true);
    $laskuhari_uid          = $info->uid;
    $laskuhari_apikey       = $info->apikey;

    // luodaan vahvistuskoodi rajapintaa varten
    $t              = time();
    $digest_src     = $laskuhari_uid."+".$t."+".$laskuhari_apikey;
    $dt = hash("sha256", $digest_src);

    // laskunluontirajapinnan URL
    $url         =  "https://oma.laskuhari.fi/api/invoice/".$invoice_number."?uid=".$laskuhari_uid."&t=".$t."&dt=".$dt;
    $post        =  "action=getpdf";
    // suoritetaan curl
    $ch = laskuhari_curl($post, $url);
    $response = curl_exec($ch);

    // tarkastetaan virheet
    if(curl_errno($ch) || stripos(".".$response, "error")) {
        update_post_meta($order_id, '_laskuhari_invoice_number', '');
        add_action( 'admin_notices', 'laskuhari_getpdf_fail' );
        return;
    }

    //ohjataan PDF-tiedostoon jos ei ollut virheitä
    wp_redirect($response);
    exit;
}

function laskuhari_getpdf_fail() {
    echo '<div class="notice notice-error is-dismissible"><p>Tilauksen PDF-laskun lataaminen epäonnistui</p></div>';
}

function laskuhari_curl($post, $url) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_FAILONERROR, 1);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
    curl_setopt($ch, CURLOPT_TIMEOUT, 100);
    curl_setopt($ch, CURLOPT_POST, TRUE);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $post);

    // laskunlähetyksen asetukset
    $info = new WC_Gateway_Laskuhari(true);
    if( $info->enforce_ssl != "yes" ) {
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, FALSE);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
    }
    
    return $ch;
}

function laskuhari_process_action($order_id, $_send_laskuhari, $order_object = false) {
    $error_notice = "";
    $success = "";
    if(is_object($order_object)) {
        $order = $order_object;
    } else {
        $order = new WC_Order($order_id);
    }
    
    // laskunlähetyksen asetukset
    $info = new WC_Gateway_Laskuhari(true);
    $laskuhari_uid          = $info->uid;
    $laskuhari_apikey       = $info->apikey;
    $sendername             = $info->laskuttaja;
    $email_message          = $info->laskuviesti;

    if($_send_laskuhari == true) {
       $lahetystapa = $info->lahetystapa_manuaalinen;
    } else {
       $lahetystapa = $info->lahetystapa;
    }

    if(trim(rtrim($email_message)) == "") {
        $email_message = "Liitteenä lasku.";
    }

    // tilaajan tiedot
    $customer               = $order->get_address('billing');
    $shippingdata           = $order->get_address('shipping');

    $shipping_different = false;
    foreach ($customer as $key => $cdata) {
        if($shippingdata[$key] != $cdata && isset($shippingdata[$key])) {
            $shipping_different = true;
            break;
        }
    }
    if(!$shipping_different) {
        foreach($shippingdata as $key => $sdata) {
            $shippingdata[$key] = "";
        }
    }

    // tilatut tuotteet
    $products           = $order->get_items();

    // summat
    $loppusumma         = $order->get_total();
    $toimitustapa       = utf8_decode($order->get_shipping_method());
    $toimitusmaksu      = $order->get_total_shipping();
    $toimitus_vero      = $order->order_shipping_tax;
    $alennus            = $order->get_total_discount();
    $cart_discount      = $order->cart_discount;
    $cart_discount_tax  = $order->cart_discount_tax;

    // luodaan vahvistuskoodi rajapintaa varten
    $t              = time();
    $digest_src     = $laskuhari_uid."+".$t."+".$laskuhari_apikey;
    $dt = hash("sha256", $digest_src);

    // laskunluontirajapinnan URL
    $url         =  "https://oma.laskuhari.fi/api/invoice?uid=".$laskuhari_uid."&t=".$t."&dt=".$dt;
    $post        =  "action=create";

    $post       .=  '&maksuehto='.
                    '&pvm='.date('d.m.Y').
                    '&lahetetty=0'.
                    '&viitteenne='.urlencode("Tilausnro. ".$order->get_order_number()).
                    '&yritys='.urlencode($customer['company']).
                    '&henkilo='.urlencode($customer['first_name'].' '.$customer['last_name']).
                    '&lahiosoite='.urlencode(trim($customer['address_1'].' '.$customer['address_2'])).
                    '&postinumero='.urlencode($customer['postcode']).
                    '&postitoimipaikka='.urlencode($customer['city']).
                    '&toimitus_yritys='.urlencode($shippingdata['company']).
                    '&toimitus_henkilo='.urlencode($shippingdata['first_name'].' '.$shippingdata['last_name']).
                    '&toimitus_lahiosoite='.urlencode(trim($shippingdata['address_1'].' '.$shippingdata['address_2'])).
                    '&toimitus_postinumero='.urlencode($shippingdata['postcode']).
                    '&toimitus_postitoimipaikka='.urlencode($shippingdata['city']).
                    '&email='.urlencode($customer['email']).
                    '&ytunnus='.
                    '&puhelin='.urlencode($customer['phone']).
                    '&teksti=';

    $i = 1;
    $laskettu_summa = 0;
    foreach($products as $data) {
        // get item prices etc. from meta array if necessary
        if(
            !isset($data['qty']) ||
            !isset($data['line_subtotal']) ||
            !isset($data['line_subtotal_tax'])||
            !isset($data['line_total'])
        ) {
            foreach($data['item_meta_array'] as $id => $object) {
                $prodata = (array)$object;
                $data[substr($prodata['key'], 1)] = $prodata['value'];
            }
        }
        $yks_veroton             = $data['line_subtotal']/$data['qty'];
        $yks_verollinen          = $yks_veroton + $data['line_subtotal_tax']/$data['qty'];
        $yht_veroton             = $data['line_subtotal'];
        $yht_verollinen          = $yht_veroton + $data['line_subtotal_tax'];
        $alv                     = ($yht_verollinen - $yht_veroton) / $yht_veroton * 100;
        $ale                     = ($yht_veroton - $data['line_total']) / $yht_veroton * 100;
        $ale                     = 0; //koska pyoristys menee sekaisin laskuharissa...

        $discount_amount         = $ale / 100 * $yht_veroton;
        $cart_discount          -= $discount_amount;
        $cart_discount_tax      -= $alv / 100 * $discount_amount;

        //kommentoitu koska pyoristys menee sekaisin laskuharissa...
        //$yht_veroton           = $data['line_total'];
        //$yht_verollinen        = $data['line_total'] + $data['line_tax'];
        
        $post .=    "&laskurivi[".$i."][tyyppi]=0".
                    "&laskurivi[".$i."][koodi]=".
                    "&laskurivi[".$i."][nimike]=".urlencode(utf8_decode($data['name'])).
                    "&laskurivi[".$i."][maara]=".urlencode($data['qty']).
                    "&laskurivi[".$i."][yks]=".
                    "&laskurivi[".$i."][veroton]=".$yks_veroton.
                    "&laskurivi[".$i."][alv]=".$alv.
                    "&laskurivi[".$i."][verollinen]=".$yks_verollinen.
                    "&laskurivi[".$i."][ale]=".$ale.
                    "&laskurivi[".$i."][yhtveroton]=".$yht_veroton.
                    "&laskurivi[".$i."][yhtverollinen]=".$yht_verollinen.
                    "&laskurivi[".$i."][toistovali]=0".
                    "&laskurivi[".$i."][ennakko]=0".
                    "&laskurivi[".$i."][jatkuvuus]=0".
                    "&laskurivi[".$i."][automaatio]=0".
                    "&laskurivi[".$i."][toistoale]=0";
        $i++;
        $laskettu_summa += $yht_verollinen;
    }


    // lisätään toimitusmaksu
    if($toimitusmaksu > 0) {
        $post .=    "&laskurivi[".$i."][tyyppi]=0".
                    "&laskurivi[".$i."][koodi]=".
                    "&laskurivi[".$i."][nimike]=".urlencode("Toimitustapa: ".$toimitustapa).
                    "&laskurivi[".$i."][maara]=1".
                    "&laskurivi[".$i."][yks]=".
                    "&laskurivi[".$i."][veroton]=".($toimitusmaksu).
                    "&laskurivi[".$i."][alv]=".round($toimitus_vero/$toimitusmaksu*100, 0).
                    "&laskurivi[".$i."][verollinen]=".($toimitusmaksu+$toimitus_vero).
                    "&laskurivi[".$i."][ale]=0".
                    "&laskurivi[".$i."][yhtveroton]=".$toimitusmaksu.
                    "&laskurivi[".$i."][yhtverollinen]=".($toimitusmaksu+$toimitus_vero).
                    "&laskurivi[".$i."][toistovali]=0".
                    "&laskurivi[".$i."][ennakko]=0".
                    "&laskurivi[".$i."][jatkuvuus]=0".
                    "&laskurivi[".$i."][automaatio]=0".
                    "&laskurivi[".$i."][toistoale]=0";

        $i++;
        $laskettu_summa += ($toimitusmaksu+$toimitus_vero);
    }

    // lisätään alennus
    if($cart_discount > 0.009) {
        $post .=    "&laskurivi[".$i."][tyyppi]=0".
                    "&laskurivi[".$i."][koodi]=".
                    "&laskurivi[".$i."][nimike]=".urlencode("Alennus").
                    "&laskurivi[".$i."][maara]=1".
                    "&laskurivi[".$i."][yks]=".
                    "&laskurivi[".$i."][veroton]=".($cart_discount*-1).
                    "&laskurivi[".$i."][alv]=".round($cart_discount_tax/$cart_discount*100, 0).
                    "&laskurivi[".$i."][verollinen]=".(($cart_discount+$cart_discount_tax)*-1).
                    "&laskurivi[".$i."][ale]=0".
                    "&laskurivi[".$i."][yhtveroton]=".($cart_discount*-1).
                    "&laskurivi[".$i."][yhtverollinen]=".(($cart_discount+$cart_discount_tax)*-1).
                    "&laskurivi[".$i."][toistovali]=0".
                    "&laskurivi[".$i."][ennakko]=0".
                    "&laskurivi[".$i."][jatkuvuus]=0".
                    "&laskurivi[".$i."][automaatio]=0".
                    "&laskurivi[".$i."][toistoale]=0";

        $i++;
        $laskettu_summa += (($cart_discount+$cart_discount_tax)*-1);
    }

    if($loppusumma != $laskettu_summa) {
        $post .=    "&laskurivi[".$i."][tyyppi]=0".
                    "&laskurivi[".$i."][koodi]=".
                    "&laskurivi[".$i."][nimike]=".urlencode("Desimaalikorjaus").
                    "&laskurivi[".$i."][maara]=1".
                    "&laskurivi[".$i."][yks]=".
                    "&laskurivi[".$i."][veroton]=".($loppusumma-$laskettu_summa).
                    "&laskurivi[".$i."][alv]=0".
                    "&laskurivi[".$i."][verollinen]=".($loppusumma-$laskettu_summa).
                    "&laskurivi[".$i."][ale]=0".
                    "&laskurivi[".$i."][yhtveroton]=".($loppusumma-$laskettu_summa).
                    "&laskurivi[".$i."][yhtverollinen]=".($loppusumma-$laskettu_summa).
                    "&laskurivi[".$i."][toistovali]=0".
                    "&laskurivi[".$i."][ennakko]=0".
                    "&laskurivi[".$i."][jatkuvuus]=0".
                    "&laskurivi[".$i."][automaatio]=0".
                    "&laskurivi[".$i."][toistoale]=0";
    }

    // suoritetaan curl
    if(!$_GET['laskuhari_invoice_number']) {
        $ch = laskuhari_curl($post, $url);
        $response = curl_exec($ch);

        // tarkastetaan virheet
        if(curl_errno($ch)) {
            $order->update_status( 'processing', $error_notice='Virhe laskun lähetyksessä. cURL errno. '.curl_errno().": ".curl_error() );
            if(function_exists('wc_add_notice')) wc_add_notice( 'Laskun automaattinen lähetys epäonnistui. Lähetämme laskun manuaalisesti.', 'notice' );
        }
        if(stripos(".".$response, "error")) {
            $order->update_status( 'processing', $error_notice='Virhe laskun lähetyksessä: '.$response );
            if(function_exists('wc_add_notice')) wc_add_notice( 'Laskun automaattinen lähetys epäonnistui. Lähetämme laskun manuaalisesti.', 'notice' );
        }

        $response            = json_decode($response, true);
        $laskunro            = $response['new_invoice_number'];
        curl_close($ch);
    } else {
        $laskunro = $_GET['laskuhari_invoice_number'];
    }

    // jatketaan vain, jos ei ollut virheitä
    if($error_notice == "") {

        update_post_meta( $order->id, '_laskuhari_invoice_number', $laskunro );

        // LASKUN LÄHETYS

        // luodaan POST-pyyntö
        $post = "action=send";
        if($customer['email'] != "") {
            $sendername      = $sendername ? $sendername : "Laskutus";
            $post           .= "&invoiceType=email";
            $post           .= "&eMailSenderName=".$sendername;
            $post           .= "&receiverEmail=".urlencode($customer['email']);
            $post           .= "&eMailSubject=Lasku";
            $post           .= "&eMailMessage=".urlencode($email_message);
            $kirjelasku      = false;
        } else {
            $kirjelasku = true;
            $post .= "&invoiceType=letter";
        }

        if(
            ($lahetystapa == "kirje" && $kirjelasku == true) ||
            ($lahetystapa == "email" && $kirjelasku == false) ||
            ($lahetystapa == "auto")            
        ) {

            // luodaan vahvistuskoodi rajapintaa varten
            $t              = time();
            $digest_src     = $laskuhari_uid."+".$t."+".$laskuhari_apikey;
            $dt = hash("sha256", $digest_src);

            // laskunlähetysrajapinnan URL
            $url        = "https://oma.laskuhari.fi/api/invoice/".($laskunro*1)."?uid=".$laskuhari_uid."&t=".$t."&dt=".$dt;

            // suoritetaan curl
            $ch         = laskuhari_curl($post, $url);
            $response   = curl_exec($ch);

            // tarkastetaan virheet
            if(curl_errno($ch)) {
                $order->update_status( 'processing', $error_notice='Virhe laskun lähetyksessä. cURL errno. '.curl_errno().": ".curl_error() );
                if(function_exists('wc_add_notice')) wc_add_notice( 'Laskun automaattinen lähetys epäonnistui. Lähetämme laskun manuaalisesti.', 'notice' );
            }
            if(stripos(".".$response, "error")) {
                $order->update_status( 'processing', $error_notice='Virhe laskun lähetyksessä: '.$response );
                if(function_exists('wc_add_notice')) wc_add_notice( 'Laskun automaattinen lähetys epäonnistui. Lähetämme laskun manuaalisesti.', 'notice' );
            }

            curl_close($ch);

            $response = json_decode($response, true);

            if($error_notice == "") {
                $order->update_status( 'processing', 'Lasku lähetetty. Odottaa maksua.' );
                update_post_meta( $order->id, '_laskuhari_sent', 'yes' );
            }

        } else {
            if($_send_laskuhari == true) {
                $success = "Tilauksen #".$order->id." lasku tallennettu Laskuhariin. Laskua ei lähetetty vielä.";
            }
            $order->update_status( 'processing', 'Odottaa laskutusta' );
        }
    }

    return array(
        "order" => $order,
        "notice" => $error_notice,
        "success" => $success
    );
}

?>